#
# spec file for package giada
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           giada
Version:        0.25.0
Release:        3.1
Summary:        Sampler Audio Tool
License:        (AGPL-3.0-only OR GPL-2.0-or-later) AND GPL-3.0-or-later AND LGPL-2.1-or-later WITH GCC-exception-2.0 AND OFL-1.1 AND Zlib
URL:            https://giadamusic.com
Source0:        %{name}-%{version}.tar.xz
Patch2:         002-fix-include-cstdint.patch
Patch3:         003-cmake-exclude-juce-from-all.patch
BuildRequires:  cmake
BuildRequires:  fltk-devel
%if 0%{?suse_version} < 1550
BuildRequires:  gcc10-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(jansson) >= 2.7
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(rtmidi) >= 2.1.0
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrandr)

%description
Giada is an audio tool for DJs and live performers. Up to 32 samples
may be loaded or recorded, and may be played in single mode (drum
machine) or loop mode (sequencer). The keyboard can be used to
control this.

%prep
%autosetup -p1

%build
test -x "$(type -p g++-10)" && export CXX=g++-10 OBJCXX=g++-10
%cmake -DCMAKE_BUILD_TYPE=Release -DWITH_VST3=ON
%cmake_build

%install
%cmake_install

%suse_update_desktop_file -c %{name} %{name} "Sampler Audio Tool" %{name} %{name} AudioVideo Audio Sequencer

%files
%doc ChangeLog
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/scalable/apps/*
%{_datadir}/metainfo/*

%changelog
* Mon Oct 16 2023 Lubos Kocman <lubos.kocman@suse.com>
- Drop the Commercial from license tag
  * It is an licensing option suggested by author, however our legaldb
    throws an error that it's not a valid SPDX license
* Tue Sep 19 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of license based on legaldb review
* Sun Jun 18 2023 Edgar Aichinger <edogawa@aon.at>
- remove 001-Fix-build-with-fmt-9-GCC-12.patch (now upstream)
- update to 0.25.0
  * Ability to change audio and MIDI engines on the fly — no need to restart
    Giada anymore when the audio and/or MIDI devices change. No need to restart
    also when changing several properties in the Configuration Window;
  * Add new "Clear" button next to all MIDI learning widgets to easily clear
    the MIDI binding (#486);
  * Set default resampler quality to "Linear" (the fastest one);
  * Update FLTK to latest commit available;
  * Update JUCE to version 7.0.5;
  * Fix Velocity parameter not being usable in Action Editor;
  * Fix MIDI Channel parameter not being usable in MIDI input configuration;
  * Code refactoring and other architectural improvements.
* Thu Mar 30 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Update patchset:
  * 001-Fix-build-with-fmt-9-GCC-12.patch
  * rename 001-cstdint.patch to 002-fix-include-cstdint.patch
- Switch to tar_scm with disabled mode
- Update to 0.24.0
  * Revamped MIDI sync Clock support
  * MIDI engine refactoring, featuring multi-threading support
  * UI: Resizable vu-meters
  * UI: New global MIDI activity leds
  * More core classes and functions refactoring
  * More robust persistence mechanism for project and configuration files
  * Add new tests suites for MidiEvent and ChannelFactory
  * Set C++ version to C++20
  * Update FLTK to latest commit available
* Wed Mar 29 2023 Edgar Aichinger <edogawa@aon.at>
- add 001-cstdint.patch to fix TW build (gcc13)
- remove tarball from package sources (generated at buildtime)
* Thu Dec 15 2022 Edgar Aichinger <edogawa@aon.at>
- update to version 0.23.2
  * 2nd bugfix release for version 0.23 Catoblepas
* Mon Sep 19 2022 Edgar Aichinger <edogawa@aon.at>
- remove giada-gcc12.patch and giada-findFLTK.patch (obsolete by upstream changes)
* Sun Sep 18 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- add 003-cmake-exclude-juce-from-all.patch to avoid juce stuff install
- disable giada-gcc12.patch (now upstream)
* Sat Sep 17 2022 Edgar Aichinger <edogawa@aon.at>
- Update to version 0.23.0
* Sun May 29 2022 Luigi Baldoni <aloisio@gmx.com>
- Add giada-gcc12.patch to fix Factory build
* Tue May 24 2022 Edgar Aichinger <edogawa@aon.at>
- workaround for gcc12 build failure in TW:
    temporarily use gcc11 until upstream fix will be available
* Wed Mar 16 2022 Edgar Aichinger <edogawa@aon.at>
- Update to version 0.21.0+git, switch to obs_scm service
- add giada-findFLTK.patch
- enable VST3 support
* Wed Jan  1 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.16.0
  * Fix columns' resizer bar height on verical window resize
  * Fix crash on MIDI learn global commands
  * Fix wrong channel routing when triggering MIDI learnt
    commands
  * Fix rewind button not rewinding sample channels in LOOP_*
    mode
  * Use actual buffer size from KernelAudio when loading
    channels from a patch
  * Remove FLTK multithreading initialization
  * Remove all pthread.h leftovers
  * Fix memory corruption on Keyboard refresh
  * Fix wave size corruption while editing samples in Sample
    Editor
  * Fix freeze when cloning a Sample Channel with a sample in it
  * Fix buffer overflow when playing an edited sample
  * Fix crash when loading a project with missing plug-ins
  * Fix freeze when pressing 'play' during an audio recording
    session
  * Fix play/ending UI status of MIDI channels
  * Fix plug-in sorting on reload
  * Fix crash when reloading a sample in the Sample Editor
  * Fix messy 'R' button status when toggled
  * Fix missing icons and broken checkboxes
  * Optimize model updates on keyboard interaction
  * Always read Columns data from patch files
  * Show missing (and removable) plug-ins in Plug-in Window list
  * Create default empty columns on 'Reset to initial state'
  * Save relative Wave paths in project files
  * New internal engine<->UI architecture
  * New persistence layer
  * New MIDI queue for incoming live MIDI messages
  * Switch to std::thread
  * Absolute #include paths in source code
  * Removed Boost parameter from Sample Channel
* Mon Apr 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.15.4
  * New record-on-signal option for input and action recording
  * Initial support for plug-ins with mono I/O buses
  * PluginHost refactoring
  * Smart pointers for Wave and Plugin objects
  * Remove old and deprecated input delay compensation
  * Optimized audio IO processing in Mixer callback
  * Atomic I/O meters with improved accuracy
  * Fix memory leak when replacing samples in a Sample Channel
  * Fix plug-ins ordering method when re-opening Giada
  * Fix silent Sample Channel when recording actions a second
    time
  * Fix velocity always discarded when sending key-press to
    Sample Channel
  * Fix inability to record actions with quantizer enabled
  version 0.15.3:
  * Action recorder refactoring
  * Optional midimap parameters (thank you @tomek-szczesny)
  * Support for "inaudible" MIDI lightning events (thank you
    @tomek-szczesny)
  * Build AppImage for Linux on Travis CI instance
  * Huge optimization of the AppImage binary file
  * Fix Action Editor repaint on min/max zoom levels
  * "Resize recording" flag has been removed
  * Change text labels for channel operations
  * Smarter column assignment while loading a patch/project
  * Fix wrong resizer bar width between Action Editor widgets
    when zooming
  * Can't display custom channel name in Sample Channel (fixed)
  * Fix crash when cloning Sample Channel with audio data in it
  * Clone channel doesn't clone channel name (fix #219)
  version 0.15.2:
  * New sample-accurate Action Editor
  * New MIDI Velocity Editor widget
  * Ability to move MIDI events vertically in piano roll (i.e.
    change note)
  * Remove mute action recording
  * Better handling of MIDI devices that send NOTEON + velocity
    0 as NOTEOFF
  * Avoid calls to deprecated JUCE plug-ins methods
  * Removed useless pthreadGC2.dll from Windows package
  * Can't kill MIDI channels (fix #197)
  * Can't record MIDI actions (fix #202)
  * Fix missing first beat on metronome rendering
  * Fix crash on opening plug-in window on macOS
  version 0.15.1:
  * Deep code refactoring, featuring Channels processors
  * Many new unit tests added
  * Simplify mutex mechanism
  * Fix wrong quantizer value on patch/project load
  * Remove the old, buggy and glitchy internal crossfade
    algorithm
  * Fix many potential plug-in crashes on Linux
  * Properly close plug-in window on plug-in removal
  * Improve BPM changes while running as JACK client
- Drop giada-gcc48.patch (no longer useful)
* Sat Apr 21 2018 jengelh@inai.de
- Ensure neutrality of description.
* Thu Apr 19 2018 aloisio@gmx.com
- Update to version 0.15.0
  * Refactor audio engine into frame-based processing
  * Refactor channels readers/writers into channelManager namespace
  * Smarter Solo algorithm
  * Fix missing .wav extension on recorded audio takes
  * Fix wrong Channel status update after 'Clear all actions'
  version 0.14.6
  * MIDI velocity drives volume for one-shot sample channels
  * FLAC and Ogg support
  * Ability to use system-provided Catch library (GitHub #151)
  * Update Catch to version 2
  * Fix unreadable tabs title in Configuration Window (GitHub #168)
  * Fix crash on opening About window
  * Fix 'read actions' button behavior during ending and waiting statuses
  version 0.14.5
  * Support for multiple plug-in directories
  * New directory browser for adding plug-in directories
  * Update plug-in's parameters on program change in plug-in's window
  * Improved MIDI action management in Piano Roll
  * Simplified conditional rules in Makefile.am
  * Fix crash on MIDI learn for plug-in parameters
  * Fix crash in MIDI input window if MIDI in params are 0
  * Fix unwanted new action when dragging piano items in Piano Roll
  * Fix crash while recording on existing project (GitHub #161)
- Dropped giada.patch (no longer necessary)
- Added giada-gcc48.patch
- Spec cleanup
* Fri Oct 27 2017 avvissu@yandex.by
- Update to 0.14.4:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Fri Oct  6 2017 avvissu@yandex.by
- Update to 0.14.3:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Tue Aug 29 2017 avvissu@yandex.by
- Update to 0.14.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Fri Jul 21 2017 avvissu@yandex.by
- Update to 0.14.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Thu May 25 2017 avvissu@yandex.by
- Update to 0.13.4:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sat Oct 22 2016 avvissu@yandex.by
- Update to 0.13.0:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Fix compilation errors on GCC 6
* Fri Jun 17 2016 avvissu@yandex.by
- Update to 0.12.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Fix build on openSUSE > 13.2 (use a supported version of GCC)
* Wed Jan 27 2016 avvissu@yandex.ru
- Update to 0.11.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Fri Dec 25 2015 avvissu@yandex.ru
- Update to 0.11.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sun Dec  6 2015 avvissu@yandex.ru
- Update to 0.11.0:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Add BuildRequires: pkgconfig(jansson)
* Wed Oct 21 2015 avvissu@yandex.ru
- Update to 0.10.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sat Sep  5 2015 avvissu@yandex.ru
- Update to 0.10.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Del -Wno-parentheses to build with gcc5 (fixed in upstream)
* Mon Jul 20 2015 avvissu@yandex.ru
- Update to 0.10.0:
  * MIDI lightning output
  * other minor fixes
* Thu Jun 25 2015 avvissu@yandex.ru
- Update to 0.9.6:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Remove patches:
  * giada-remove_build_timestamps.patch (use sed)
  * giada-add_missing_link_to_Xinerama.patch (fix to upstream)
- Add new package: rtmidi-devel libpulse-devel
- Build with gcc5: disable check:-Wno-parentheses
- Fix files is compiled without RPM_OPT_FLAGS
- Remove giada.desktop: use %%%%suse_update_desktop_file
- Add %%%%icon_theme_cache_(post,postun)
- Spec file cleanup
* Tue May 29 2012 pascal.bleser@opensuse.org
- update to 0.4.10:
  - Ability to shift up an down VST plugins
  - Enhanced patch/conf architecture
  - Ability to edit a sample while playing
  - Mutex controls in VST processing
  - Lots of security issues fixed while changing pitch dynamically
  - Enhanced sub-window system
  - Several minor bugs fixed
- changes from 0.4.9:
  - No more mandatory inputs
  - Pitch value properly stored inside the patch
  - Several small VST host improvements
  - Enhanced window management
  - Ability to browse files while playing with main GUI (non-modal browser)
  - Improved error checking in KernelAudio
  - Wrong style for lower scrollbar in Browser (fixed)
  - Fixed compilation on 64 bit systems
  - Samplerate no longer hardcoded, auto-detected with JACK
  - Minor internal improvements and bugfixing
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- initial version (0.4.8)
